==> bundesliga_tippspiel-1.9.2-py3-none-any.whl: bundesliga_tippspiel/routes/api/putters.py <==
"""LICENSE
Copyright 2017 Hermann Krumrey <hermann@krumreyh.com>

This file is part of bundesliga-tippspiel.

bundesliga-tippspiel is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

bundesliga-tippspiel is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with bundesliga-tippspiel.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from flask import request, Blueprint
from flask_login import login_required
from puffotter.flask.routes.decorators import api, api_login_required
from bundesliga_tippspiel.actions.PlaceBetsAction import PlaceBetsAction
from bundesliga_tippspiel.actions.SetReminderSettingsAction import \
    SetReminderSettingsAction


def define_blueprint(blueprint_name: str) -> Blueprint:
    """
    Defines the blueprint for this route
    :param blueprint_name: The name of the blueprint
    :return: The blueprint
    """
    blueprint = Blueprint(blueprint_name, __name__)

    @blueprint.route("/api/v2/bet", methods=["PUT"])
    @api_login_required
    @login_required
    @api
    def put_bet():
        """
        Allows the placement of new bets
        :return: None
        """
        action = PlaceBetsAction.from_dict(request.get_json())
        return action.execute()

    @blueprint.route("/api/v2/reminder", methods=["PUT"])
    @api_login_required
    @login_required
    @api
    def put_reminder():
        """
        Allows the creation or updating of an email reminder
        :return: None
        """
        action = SetReminderSettingsAction.from_dict(request.get_json())
        return action.execute()

    return blueprint

==> bundesliga_tippspiel-1.10.0-py3-none-any.whl: bundesliga_tippspiel/routes/api/putters.py <==
"""LICENSE
Copyright 2017 Hermann Krumrey <hermann@krumreyh.com>

This file is part of bundesliga-tippspiel.

bundesliga-tippspiel is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

bundesliga-tippspiel is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with bundesliga-tippspiel.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from flask import request, Blueprint
from flask_login import login_required
from jerrycan.routes.decorators import api, api_login_required
from bundesliga_tippspiel.actions.PlaceBetsAction import PlaceBetsAction
from bundesliga_tippspiel.actions.SetReminderSettingsAction import \
    SetReminderSettingsAction


def define_blueprint(blueprint_name: str) -> Blueprint:
    """
    Defines the blueprint for this route
    :param blueprint_name: The name of the blueprint
    :return: The blueprint
    """
    blueprint = Blueprint(blueprint_name, __name__)

    @blueprint.route("/api/v2/bet", methods=["PUT"])
    @api_login_required
    @login_required
    @api
    def put_bet():
        """
        Allows the placement of new bets
        :return: None
        """
        action = PlaceBetsAction.from_dict(request.get_json())
        return action.execute()

    @blueprint.route("/api/v2/reminder", methods=["PUT"])
    @api_login_required
    @login_required
    @api
    def put_reminder():
        """
        Allows the creation or updating of an email reminder
        :return: None
        """
        action = SetReminderSettingsAction.from_dict(request.get_json())
        return action.execute()

    return blueprint
